rule!() { /* proc-macro */ }Expand description
Expands a grammar-shaped expression into a nom parser.
See the crate-level documentation for terminal matcher expectations, syntax, precedence, and output shapes.
rule!() { /* proc-macro */ }Expands a grammar-shaped expression into a nom parser.
See the crate-level documentation for terminal matcher expectations, syntax, precedence, and output shapes.